#!/bin/bash

# Maintenance
if [[ $1 == 'clean' ]]
then
	rm -rf /var/run/serverforge/downloads/*
fi

echo ""

# Get ServerForge
if [[ $1 != 'local' ]]
then
	
	curl https://mirrors.gethosted.online/serverforge/serverforge-0.1.tar.gz -O
	dnf -y install tar
	tar -zxf serverforge-0.1.tar.gz
	mv serverforge /usr/local/
fi

# Setup Environment
mkdir -p /var/run/serverforge
mkdir -p /var/run/serverforge/downloads

# Set Permissions
chmod -R +x /usr/local/serverforge/bin

# Go to root folder
cd /usr/local/serverforge/bin

# Logging
mkdir -p /var/log/serverforge
echo '' > /var/log/serverforge/install.log

# Prerequisites
pre="wget pam-devel libpsl libpsl-devel libzip libzip-devel krb5-devel krb5-libs expat expat-devel bison bison-devel autoconf re2c pcre pcre-devel libtool sqlite bzip2 bzip2-devel gettext libtool git rsync openssl openssl-devel virt-install libvirt qemu-kvm icu libicu-devel libpng-devel epel-release libxml2 libxml2-devel sqlite sqlite-devel tar perl libxslt libxslt-devel libyaml-devel libacl libacl-devel libcurl libcurl-devel platform-python-devel openldap openldap-devel tar jansson jansson-devel expat expat-devel perl perl-devel pcre-devel libxml2 libxml2-devel iptables sendmail libnghttp2 php-pear oniguruma oniguruma-devel psmisc libyaml libyaml-devel perl-libwww-perl perl-LWP-Protocol-https perl-GDGraph perl-Math-BigInt"
if [[ -f /usr/bin/dnf ]]
then
	
    # RHEL 9
    dnf config-manager --set-enabled crb
	dnf -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-9.noarch.rpm
	/usr/bin/crb enable
	
    # RHEL 8
    if [[ -f /etc/yum.repos.d/*-powertools.repo ]]
	then
		sed -i 's/enabled=0/enabled=1/g' /etc/yum.repos.d/*-powertools.repo
	fi
	
    dnf -y groupinstall "Development Tools"
    dnf -y install $pre

elif [[ -f /usr/bin/yum ]]
then
	yum -y install $pre  
elif [[ -f /usr/bin/apt-get ]]
then
	apt-get update
	apt-get install $pre 
elif [[ -f /usr/bin/pkg_add ]]
then
	pkg_add -r  $pre
elif [[ -f /usr/bin/pkg ]]
then
	pkg install $pre  
else
	echo "Warning: Prerequisites not installed"
fi


# MOTD
if [[ ! -f /usr/local/bin/motd.sh ]]
then
	cp src/motd.sh /usr/local/bin/motd.sh
	chmod +x /usr/local/bin/motd.sh
	
	if [[ `cat /etc/profile` != *"/usr/local/bin/motd.sh"* ]]; then
		echo "# ServerForge MOTD" >> /etc/profile
		echo "/usr/local/bin/motd.sh" >> /etc/profile
		echo ""
		echo "# ServerForge Aliases" >> /etc/profile
		echo "alias htdocs='cd /usr/local/apache/htdocs'" >> /etc/profile
		echo "alias sf='/usr/local/serverforge/bin/serverforge'" >> /etc/profile
		echo "alias dnf='dnf -y'" >> /etc/profile
		
	fi
fi



# Prerequisites
./src/csf.sh
./src/apr.sh
./src/libxml.sh
./src/pcre.sh

# Now, Apache
./src/apache.sh

# Next, install PHP
./src/php.sh

# Create Service
echo "
[Unit]
Description=ServerForge System
After=network.target remote-fs.target nss-lookup.target

[Service]
Type=forking
ExecStart=/var/run/serverforge/apache/bin/httpd -k start -f /var/run/serverforge/apache/conf/httpd.conf
ExecStop=/var/run/serverforge/apache/bin/httpd -k stop -f /var/run/serverforge/apache/conf/httpd.conf
ExecReload=/var/run/serverforge/apache/bin/httpd -k graceful -f /var/run/serverforge/apache/conf/httpd.conf
PrivateTmp=true
LimitNOFILE=infinity

[Install]
WantedBy=multi-user.target
" > /etc/systemd/system/serverforge.service;


# Other Commands
ldconfig /usr/local/lib64
setenforce 0

# Virtual Machines
systemctl enable libvirtd
systemctl start libvirtd

# Start Service	
/usr/bin/systemctl daemon-reload
/usr/bin/systemctl enable serverforge
/usr/bin/systemctl restart serverforge

# Symbolic Links
ln -s /usr/local/serverforge/bin/serverforge /usr/local/bin/serverforge
ln -s /usr/local/serverforge/bin/serverforge /usr/local/bin/sf
ln -s /usr/local/serverforge/bin/serverforge /usr/local/bin/run

